CedarBackup3.release — cedar-backup3 3.10.0 documentation

# CedarBackup3.release

Provides a location to maintain version information.

## Module Attributes

CedarBackup3.release.AUTHOR

  Author of software

CedarBackup3.release.EMAIL

  Email address of author

CedarBackup3.release.VERSION

  Software version

CedarBackup3.release.URL

  Homepage URL

author:

  Kenneth J. Pronovici <pronovic@ieee.org>

## Module Contents

CedarBackup3.release.AUTHOR

CedarBackup3.release.EMAIL

CedarBackup3.release.VERSION

CedarBackup3.release.URL

CedarBackup3.release.COPYRIGHT = 'unset'

CedarBackup3.release.DATE = 'unset'